@@ -154,6 +154,7 @@ analyse_hydraulic = function(
 		# determine opening scenario
 		data_hyd = prepare_hydraulic_input(
 			model,
+			opening_scenario = opening_scenario,
 			exposition = limnigraph[["exposition"]],
 			clearance = clearance,
 			permeability = permeability
@@ -169,8 +170,11 @@ analyse_hydraulic = function(
 		room[["v"]] = room[["surface"]] * room[["ceiling_H"]] / 100
 
 		r_names_to_merge = NULL
+		wall = model[["data_table"]][["wall"]]
+		# selection on internal walls only
+		sel = wall[!is.na(wall[["room_name"]]), ]
 		# in case of invisible walls, merge rooms
-		if("empty" %in% model[["data_table"]][["wall"]][["type"]])
+		if("empty" %in% sel[["type"]])
 		{
 			r_names_to_merge = find_room_to_merge(model, verbose)
 		}
