@@ -106,6 +106,8 @@ find_exchange = function(x, opening) {
 #' Extract hydraulic input data from model
 #' 
 #' @param model an object of class model
+#' @param opening_scenario character, one of the following options: "open",
+#' 		"close", "combine".
 #' @param exposition list, contains list of `facade` exposed to the flood event.
 #' 	Each `facade` is a list of named vectors of the walls exposed in the same
 #' 	way. Vectors are named after the `external` they belong to in the model.
@@ -130,6 +132,7 @@ find_exchange = function(x, opening) {
 prepare_hydraulic_input = function(
 		model,
 		exposition,
+		opening_scenario,
 		initial_water_depth_interior = getOption("floodam_building_hydraulic_initial_water_depth_interior"),
 		discharge_coefficient =	getOption("floodam_building_hydraulic_discharge_coefficient"),
 	 	clearance = getOption("floodam_building_hydraulic_close_opening_clearance"),
@@ -221,7 +224,9 @@ prepare_hydraulic_input = function(
 		op_combine = rbind(op_combine_width, op_combine)
 
 		name = op_combine[["opening"]]
-		op_open = op_open[op_open[["opening"]] %in% name, ]
+		if (opening_scenario == "combine") {
+			op_open = op_open[op_open[["opening"]] %in% name, ]
+		}
 	} else {
 		op_combine[[side]][op_ext] = clearance / 100
 	}
